Index: WAeUP_SRP/trunk/skins/waeup_layout/layout_apply_admission_view.pt
===================================================================
--- WAeUP_SRP/trunk/skins/waeup_layout/layout_apply_admission_view.pt	(revision 4523)
+++ WAeUP_SRP/trunk/skins/waeup_layout/layout_apply_admission_view.pt	(revision 4524)
@@ -11,5 +11,5 @@
          tal:condition="ds/pin|nothing"/>
   <input type="submit" class="standalone" name="slip"
-         value="Print Aknowledgement Slip"
+         value="Print Acknowledgement Slip"
          />
 </form>
Index: WAeUP_SRP/trunk/skins/waeup_student/apply_admission.py
===================================================================
--- WAeUP_SRP/trunk/skins/waeup_student/apply_admission.py	(revision 4523)
+++ WAeUP_SRP/trunk/skins/waeup_student/apply_admission.py	(revision 4524)
@@ -48,13 +48,13 @@
 
 headings_slip = {}
-headings_slip['pume'] = 'Post UME Screening (2009/2010) Aknowledgement Slip!'
-headings_slip['pde'] = 'Post UDE Screening (2009/2010) Aknowledgement Slip'
-headings_slip['prence'] = 'Pre-NCE Application (2007/2008) Aknowledgement Slip'
-headings_slip['pce'] = 'PCE Screening (2007/2008) Aknowledgement Slip'
-headings_slip['cest'] = 'CEST Application (2008/2009) Aknowledgement Slip'
-headings_slip['pt'] = 'Part-Time Degree Application (2009/2010) Aknowledgement Slip'
-headings_slip['dp'] = 'Diploma Programme Application (2009/2010) Aknowledgement Slip'
-headings_slip['ct'] = 'Certificate Programme Application (2009/2010) Aknowledgement Slip'
-headings_slip['sandwich'] = 'Application for Part Time Degree in Education (2008/2009) Aknowledgement Slip'
+headings_slip['pume'] = 'Post UME Screening (2009/2010) Acknowledgement Slip!'
+headings_slip['pde'] = 'Post UDE Screening (2009/2010) Acknowledgement Slip'
+headings_slip['prence'] = 'Pre-NCE Application (2007/2008) Acknowledgement Slip'
+headings_slip['pce'] = 'PCE Screening (2007/2008) Acknowledgement Slip'
+headings_slip['cest'] = 'CEST Application (2008/2009) Acknowledgement Slip'
+headings_slip['pt'] = 'Part-Time Degree Application (2009/2010) Acknowledgement Slip'
+headings_slip['dp'] = 'Diploma Programme Application (2009/2010) Acknowledgement Slip'
+headings_slip['ct'] = 'Certificate Programme Application (2009/2010) Acknowledgement Slip'
+headings_slip['sandwich'] = 'Application for Part Time Degree in Education (2008/2009) Acknowledgement Slip'
 configuration += ('heading_slip',headings_slip),
 
Index: WAeUP_SRP/trunk/skins/waeup_student/apply_admission_2.py
===================================================================
--- WAeUP_SRP/trunk/skins/waeup_student/apply_admission_2.py	(revision 4523)
+++ WAeUP_SRP/trunk/skins/waeup_student/apply_admission_2.py	(revision 4524)
@@ -43,5 +43,5 @@
 configuration += ('heading',headings),
 headings_slip = {}
-headings_slip['cest'] = 'CEST Application (2008/2009) Aknowledgement Slip'
+headings_slip['cest'] = 'CEST Application (2008/2009) Acknowledgement Slip'
 configuration += ('heading_slip',headings_slip),
 

Index: WAeUP_SRP/trunk/skins/waeup_fceokene/apply_admission.py
===================================================================
--- WAeUP_SRP/trunk/skins/waeup_fceokene/apply_admission.py	(revision 4523)
+++ WAeUP_SRP/trunk/skins/waeup_fceokene/apply_admission.py	(revision 4524)
@@ -47,12 +47,12 @@
 configuration += ('heading',headings),
 headings_slip = {}
-headings_slip['pume'] = 'Post UME Screening (2008/2009) Aknowledgement Slip!'
-headings_slip['pde'] = 'Post UDE Screening (2008/2009) Aknowledgement Slip'
-headings_slip['prence'] = 'Pre-NCE Application (2009/20010) Aknowledgement Slip'
-headings_slip['pce'] = 'PCE Screening (2007/2008) Aknowledgement Slip'
-#headings_slip['cest'] = 'Common Entrance Screening (2007/2008) Aknowledgement Slip'
-headings_slip['cest'] = 'CEST Application (2008/2009) Aknowledgement Slip'
-headings_slip['sandwich'] = 'Application for Sandwich Programme (2009/2010) Aknowledgement Slip'
-#headings_slip['pt'] = 'Part Time (2007/2008) Aknowledgement Slip'
+headings_slip['pume'] = 'Post UME Screening (2008/2009) Acknowledgement Slip!'
+headings_slip['pde'] = 'Post UDE Screening (2008/2009) Acknowledgement Slip'
+headings_slip['prence'] = 'Pre-NCE Application (2009/20010) Acknowledgement Slip'
+headings_slip['pce'] = 'PCE Screening (2007/2008) Acknowledgement Slip'
+#headings_slip['cest'] = 'Common Entrance Screening (2007/2008) Acknowledgement Slip'
+headings_slip['cest'] = 'CEST Application (2008/2009) Acknowledgement Slip'
+headings_slip['sandwich'] = 'Application for Sandwich Programme (2009/2010) Acknowledgement Slip'
+#headings_slip['pt'] = 'Part Time (2007/2008) Acknowledgement Slip'
 configuration += ('heading_slip',headings_slip),
 